@@ -1,20 +1,13 @@
 package Gtk2::Ex::DbLinker::DbcDataManager;
 use  Gtk2::Ex::DbLinker::DbTools;
 our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
-
-use Class::Interface;
-
-&implements('Gtk2::Ex::DbLinker::AbDataManager');
-
 use strict;
 use warnings;
+use interface qw(Gtk2::Ex::DbLinker::AbDataManager);
 use  Carp qw(carp croak confess cluck);
 use Data::Dumper;
 use Try::Tiny;
 
-$Class::Interface::CONFESS = 1;
-
-
 my %fieldtype = (
 	tinyint => 'integer',
 );
@@ -31,16 +24,19 @@ my %fieldtype = (
 #row_count (which is the resultset->count) will reflect this changes.
 
 sub new {
-	 my ( $class, $req ) = @_;
+	# my ( $class, $req ) = @_;
+	my $class = shift;
+	my %def =(page=>1);
+	my %arg = (ref $_[0] eq "HASH" ? (%def, %{$_[0]}) : (%def, @_));
 	my $self = {
-		page => $$req{pate} || 1,
-		rec_per_page => $$req{rec_per_page} || 1,
-		rs => $$req{rs},
-		primary_keys => $$req{primary_keys},
-		ai_primary_keys => $$req{ai_primary_keys},
-		cols_types => $$req{columns},
-		'+cols_types' => $$req{'+columns'},
-		defaults => $$req{defaults},
+		page => $arg{page} || 1,
+		rec_per_page => $arg{rec_per_page} || 1,
+		rs => $arg{rs},
+		primary_keys => $arg{primary_keys},
+		ai_primary_keys => $arg{ai_primary_keys},
+		cols_types => $arg{columns},
+		'+cols_types' => $arg{'+columns'},
+		defaults => $arg{defaults},
 
 
 	 };
@@ -498,31 +494,31 @@ use a ResultSet object from the table(s) you want to display
 
 Pass this object to the DbcDataManager constructor 
 
-	 my $dbcm = Linker::DbcDataManager->new({ rs => $rs});
+	 my $dbcm = Linker::DbcDataManager->new( rs => $rs );
 
 =back
 
 To link the data with a Gtk window, the Gtk entries id in the glade file have to be set to the names of the database fields
 
-	  $self->{linker} = Linker::Form->new({ 
+	  $self->{linker} = Linker::Form->new( 
 		    data_manager => $dbcm,
 		    builder =>  $builder,
 		    rec_spinner => $self->{dnav}->get_object('RecordSpinner'),
   	    	    status_label=>  $self->{dnav}->get_object('lbl_RecordStatus'),
 		    rec_count_label => $self->{dnav}->get_object("lbl_recordCount"),
-	    });
+	    );
 
 To add a combo box in the form, the first field given in fields array will be used as the return value of the combo. 
 noed is the Gtk2combo id in the glade file and the field's name in the table that received the combo values.
 	 
-	my $dman = Gtk2::Ex::DbLinker::DbcDataManager->new({rs => $self->{schema}->resultset('Ed')->search_rs( undef, {order_by => ['nom']} ) } );
+	my $dman = Gtk2::Ex::DbLinker::DbcDataManager->new(rs => $self->{schema}->resultset('Ed')->search_rs( undef, {order_by => ['nom']} )  );
 
 
-	$self->{linker}->add_combo({
+	$self->{linker}->add_combo(
     	data_manager => $dman,
     	id => 'noed',
 	fields => ["id", "nom"],
-      });
+      );
 
 
 And when all combos or datasheets are added:
@@ -553,7 +549,10 @@ This module fetch data from a dabase using DBIx::Class.
 
 =head2 constructor
 
-The parameters is passed in a hash reference with the key C<rs>.
+The parameter is passed as a list of parameter name => value or as a hash reference with the parameter name as key.
+
+The unique parameter is C<rs>.
+
 The value for C<rs> is a DBIx::Class::ResultSet object.
 
 		my $rs = $self->{schema}->resultset("Table")->search_rs(undef, {order_by => 'title'});
