@@ -1,39 +1,36 @@
 package Gtk2::Ex::DbLinker::DbiDataManager;
 use  Gtk2::Ex::DbLinker::DbTools;
 our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
-
-use Class::Interface;
-
-&implements('Gtk2::Ex::DbLinker::AbDataManager');
-
 use strict;
 use warnings;
+use interface qw(Gtk2::Ex::DbLinker::AbDataManager);
 use  Carp  qw(carp croak confess cluck);
 use Data::Dumper;
 use Try::Tiny;
 use base qw(Gtk2::Ex::DbLinker::Recordset);
-
 #my %fieldtype = (tinyint => "integer", "int" => "integer");
 
-$Class::Interface::CONFESS = 1;
-
 sub new {
-		my ( $class, $req ) = @_;
-		my $self = $class->SUPER::new({aperture => $$req{aperture}});
-		$self->{dbh} = $$req{dbh}; # A database handle
-    		$self->{primary_keys} = $$req{primary_keys}; # An array ref of primary keys
-		$self->{sql}= $$req{sql}; # A hash of SQL related stuff
-		$self->{before_query} = $$req{before_query};
-		$self->{defaults} = $$req{defaults};
-		$self->{ro_fields} = $$req{ro_fields}; #fields from join tables that are not updatable
+	#my ( $class, $req ) = @_;
+	my $class = shift;
+	my %def=();
+	my  %arg = (ref $_[0] eq "HASH" ? (%def, %{$_[0]}) : (%def, @_));
+
+		my $self = $class->SUPER::new(batch_size => $arg{aperture});
+		$self->{dbh} = $arg{dbh}; # A database handle
+    		$self->{primary_keys} = $arg{primary_keys}; # An array ref of primary keys
+		$self->{sql}= $arg{sql}; # A hash of SQL related stuff
+		$self->{before_query} = $arg{before_query};
+		$self->{defaults} = $arg{defaults};
+		$self->{ro_fields} = $arg{ro_fields}; #fields from join tables that are not updatable
 
 # an array of auto incremented primary keys
 # and I want to test if it has been set to undef to forcibly set auto_imcrementing to 0
- 		$self->{ai_primary_key} = $$req{ai_primary_key} if (exists ($$req{ai_primary_key})); 														
+ 		$self->{ai_primary_key} = $arg{ai_primary_key} if (exists ($arg{ai_primary_key})); 														
 	# bless $self, $class;
 
  $self->{log} = Log::Log4perl->get_logger(__PACKAGE__);
-
+ # $self->{log}->debug("args\n", Dumper(%arg));
 
  $self->{auto_incrementing} = ( defined ($self->{ai_primary_key}) ? 1 : 0);
 	confess(__PACKAGE__ . ": use ai_primary_key or primary_keys but not both...") if (defined $self->{ai_primary_key} && defined $self->{primary_keys});
@@ -46,7 +43,7 @@ sub new {
 
 
  if ($self->{sql}->{select_distinct}) {
-	$self->{sql}->{select}=$req->{sql}->{select_distinct};
+	$self->{sql}->{select}=$arg{sql}->{select_distinct};
 	$self->{sql}->{head}="select distinct ";
 	  
   } else {
@@ -147,17 +144,29 @@ sub new {
 #query is called by the constructor if a where clause or if pass_through as  have been setted
 #query is called as a method on an existing datamanager to change the rows
 sub query {
-	 my ( $self,  $where_object ) = @_;
-	$self->{log}->debug("query " . Dumper($where_object));
+	#my ( $self,  $where_object ) = @_;
+	my $self = shift;
+	 my %h;
+	 my $where ;
+	 # if ( defined $_[0] ) {
+	$where = (ref $_[0] eq "HASH")? $_[0] : (defined $_[0] ? (%h =( @_)) && \%h : {});
+	#} else {
+	#	$where = {};
+	#}
+	$self->{log}->debug("query " . Dumper($where));
 	# $self->{log}->debug("inserting is " . (defined $self->{inserting} && $self->{inserting} ? " true " : " false or undef"));
-	if ( $where_object->{where} ) {
-              $self->{sql}->{where} = $where_object->{where};
+	if ( $where->{where} ) {
+              $self->{sql}->{where} = $where->{where};
           }
 
-         if ( $where_object->{bind_values} ) {
-		 $self->{log}->debug("bind_values received", join(" ", @{$where_object->{bind_values}}) );
-                $self->{sql}->{bind_values} = $where_object->{bind_values};
-         }
+         if ( $where->{bind_values} ) {
+		 $self->{log}->debug("bind_values received", join(" ", @{$where->{bind_values}}) );
+                $self->{sql}->{bind_values} = $where->{bind_values};
+         } else {
+		 #added 2016-08 because call like "where 1=1"
+		 #did not work if the DM stored bin_values
+	 	$self->{sql}->{bind_values} = undef;
+	 }
 
              # Execute any before_query code
     if ( $self->{before_query} ) {
@@ -212,16 +221,16 @@ sub query {
 	};
         
 	#die $local_sql;
-
+#$self->{log}->debug("bind values received in the sub :\n" . Dumper( $where->{bind_values}));
+$self->{log}->debug("bind values stored in the DM :\n" .Dumper($self->{sql}->{bind_values}));
 
         try {
-            if ( $where_object->{bind_values} ) {
-                $sth->execute( @{$where_object->{bind_values}} );
-            } elsif ( $self->{sql}->{bind_values} ) {
-                $sth->execute( @{$self->{sql}->{bind_values}} ) ;
-            } else {
-	    	$sth->execute;
-	    }
+	      if ( $self->{sql}->{bind_values} ) {
+                      $sth->execute( @{$self->{sql}->{bind_values}} ) ;
+                 } else {
+	    	      $sth->execute;
+	     }
+	    
         } catch { 
 		confess $self->{dbh}->errstr . " ".  $local_sql;
 	};
@@ -296,7 +305,9 @@ sub _get_rows_from_batch {
        my %rows;
 	for my $pk (@pks) {	
        		for (my $i =0; $i < $last ; $i++) {
-			$rows{$i}.=  $pk_vals->[$i]. ", ";
+			my $val = $pk_vals->[$i];
+			$val = $val ^ $val ? "'" . $val . "'" : $val ; #enclose $val between ' if $val is non numeric
+			$rows{$i}.=  $val . ", ";
 			#$self->{log}->debug("row:", $i, " : ", $rows{$i});
 		}
 		$pk_order++;
@@ -327,8 +338,10 @@ sub _get_rows_from_batch {
 }
 
 sub save{
-	my ($self,  $href) = @_;
-    
+      #	my ($self,  $href) = @_;
+    	my $self = shift;
+	my %h;
+	 my $href = (ref $_[0] eq "HASH" ? $_[0] : (%h = (@_)) && \%h);
     my @fieldlist = ();
     my @bind_values = ();
     #$href is used to change a field's value when the field is included in a composed primary keys. 
@@ -433,10 +446,11 @@ my $done=1;
         }
 	$self->add_pkvalues(\@keys);
         $self->{log}->debug( join(", ", @keys) . " added to keyset");
-
-        
+	if ($done){
+        	$self->{inserting} = 0; 
+		$self->{log}->debug("turn off inserting flag");
+	}
     }
-    $self->{inserting} = 0;
     return $done;
 }#save
 
@@ -505,25 +519,25 @@ See Version in L<Gtk2::Ex::DbLinker::DbTools>
 
 To fetch the data from the a whole table
 
-	  my $rdbm = Gtk2::Ex::DbLinker::DbiDataManager->new({
+	  my $rdbm = Gtk2::Ex::DbLinker::DbiDataManager->new(
 		 	dbh => $dbh,
 			sql =>{from => "mytable",
 			select => "pk_id, field1, field2, field3",
 			where => "1=1",
 		},
-	 });
+	 );
 
 To link the data with a Gtk windows, have the Gtk entries ID, or combo ID in the xml glade file set to the name of the database fields: pk_id, field1, field2...
 
-	  $self->{form} = Gtk2::Ex::DbLinker::Form->new({ 
+	  $self->{form} = Gtk2::Ex::DbLinker::Form->new( 
 		    data_manager => $rdbm,
 		    builder =>  $builder,
 		   ...
-	    });
+	    );
 
 To add a combo box in the form:
 
-	  my $dman = Gtk2::Ex::DbLinker::DbiDataManager->new({
+	  my $dman = Gtk2::Ex::DbLinker::DbiDataManager->new(
 			dbh => $dbh,
 			sql => {
 				select => "id, name",
@@ -531,15 +545,15 @@ To add a combo box in the form:
 				order_by => "name ASC",
 				where => "1=1",
 				},
-		});
+		);
 
 The first field given in the select value will be used as the return value of the combo.
 C<noed> is the Gtk2combo id in the glade file and the field's name in the table displayed in the form.
 
-    $self->{form}->add_combo({
+    $self->{form}->add_combo(
     	data_manager => $dman,
     	id => 'noed',
-      });
+      );
 
 And when all combos or datasheets are added:
 
@@ -553,9 +567,9 @@ In the subform_a module:
 
 	sub on_pk_changed {
 		 my ($self,$value) = @_;
-		$self->{jrn_coll}->get_data_manager->query({ where =>"pk_value_of_the_bound_table = ?", 
+		$self->{jrn_coll}->get_data_manager->query( where =>"pk_value_of_the_bound_table = ?", 
 								bind_values => [ $value ],
-							   });
+							   );
 		...
 		}
 
@@ -567,7 +581,10 @@ This module fetches data from a dabase using DBI and sql commands. A new instanc
 
 =head2 constructor
 
-The parameters to C<new> are passed in a hash reference with the keys C<dbh>, C<sql>, C<primary_keys>, C<ai_primary_key>.
+The parameters to C<new> are passed as a list of parameters name => values, or as a hash reference with the parameters name as keys.
+
+Paramters are  C<dbh>, C<sql>, C<primary_keys>, C<ai_primary_key>.
+
 The value for C<primary_keys> and C<ai_primary_key> are arrayrefs holding the field names of the primary key and auto incremented primary keys. 
 If the table use a autogenerated key, use ai_primary_key instead of primary_keys to set these.
 C<dbh>, C<sql> are mandatory.
@@ -642,7 +659,7 @@ C<pass_through> :  an sql string that will be executed in the DB. Rows are read
 
 =back
 
-	Gtk2::Ex::DbLinker::DbiManager->new({ dbh => $dbh,
+	Gtk2::Ex::DbLinker::DbiManager->new( dbh => $dbh,
 					    sql => {
 							select_distinct => "abo.ref as ref, ...",
 							from   => "abo INNER JOIN jrnabt ON abo.noabt = jrnabt.noabt",
@@ -650,22 +667,24 @@ C<pass_through> :  an sql string that will be executed in the DB. Rows are read
 							order_by =>"abo.type ASC, abo.ref ASC",
 							bind_values=> [ $nofm_value ],
 						}
-				});
+				);
 
-=head2 C<query({ where => "pk=?" , bind_values=>[ $value ] });
+=head2 C<query( where => "pk=?" , bind_values=>[ $value ] );
 
 To display an other set of rows in a form, call the query method on the datamanager instance for this form.
 Return the number of rows retrieved.
 
 	my $dman = $self->{form_a}->get_data_manager();
 
-	$dman->query({where=>"nofm=?", bind_values=>[ $f->{nofm} ]});
+	$dman->query(where=>"nofm=?", bind_values=>[ $f->{nofm} ]);
 	
 	$self->{form_a}->update;
 
 C<query> will not place the recordset cursor, but in the above example C<update> on the Form (or a Datasheet) instance will. Be sure to call C<set_row_pos(0)> on the datamanager object after C<query( ... )> in others situations.
 
-The parameter of the query method is a hash reference with the folowing key / value pairs:
+The parameter of the query method is a list of parmaters name => values, or a hash reference with the keys as parameters name.
+
+Parameters are:
 
 =over
 
@@ -683,9 +702,9 @@ C<bind_values> : a array reference holding the value(s) corresponding to the pla
 
 Build the sql commands tu insert a new record or update an existing record. Fetch the value from auto_incremented primary key.
 
-=head2 C<save({ $field_name => $value });>
+=head2 C<save( $field_name => $value );>
 
-Pass a href as a parameter when a value has to be saved in the database without using C< $dman->set_field($ field, $value ) >. Use this when you want to change a field that is part of a multiple fields primary key.
+Pass a list or a hash reference as a parameter when a value has to be saved in the database without using C< $dman->set_field($ field, $value ) >. Use this when you want to change a field that is part of a multiple fields primary key.
 
 =head2 C<new_row();>
 
