@@ -21,6 +21,7 @@ sub new {
 		rec_per_page => $arg{rec_per_page},
 		data => $arg{data},
 		meta => $arg{meta},
+		alias => $arg{alias},
 		columns => $arg{columns},
 		'+columns' => $arg{'+columns'},
 		primary_keys => $arg{primary_keys},
@@ -90,6 +91,9 @@ sub set_field{
 	my ($self, $id, $value) = @_;
 	my $pos =  $self->{row}->{pos};
 	my $row;
+	if ($self->{isalias}->{$id}){ 
+		$id = $self->{isalias}->{$id};
+	}
 	my $rel = $self->{fieldsRel}->{$id};
 	$rel = ($rel ? $rel : "");
 	my $key = $rel . $id;
@@ -126,6 +130,9 @@ sub get_field{
 	} else {
 		$self->{log}->debug("current pos outside row limits");
 	}
+	if ($self->{isalias}->{$id}){ 
+		$id = $self->{isalias}->{$id};
+	}
 	my $rel = $self->{fieldsRel}->{$id};
 	$rel = ( $rel ? $rel : "");
 	my $key = $rel . $id;
@@ -136,7 +143,7 @@ sub get_field{
 		$self->{log}->debug("get_field " . $id . " rel: " . $rel . " method: " . $m);
 		$v = $row->{$rel}->$m(); # or croak(__PACKAGE__ . "1 no method found to get value from the column " . $rel . " + " . $id);
 	} else {
-		$self->{log}->debug("get_field " . $id . " method: " . $m);
+		$self->{log}->debug("get_field " . $id . " method: " . (defined $m ? $m : " undefined") );
 		$v = $row->$m(); # or croak(__PACKAGE__ . " no method found to get value from the column " . $id);
 	}
 	return $v;
@@ -235,6 +242,9 @@ sub get_field_names {
 #param : the field name
 sub get_field_type {
 	my ($self, $id) = @_;
+	if ($self->{isalias}->{$id}){ 
+		$id = $self->{isalias}->{$id};
+	}
 	my $rel = $self->{fieldsRel}->{$id};
 	$rel = ( $rel ? $rel : "");
 	my $key = $rel . $id;	
@@ -336,7 +346,17 @@ sub _init {
 		$self->{ai_primary_keys} = \@apk unless ($self->{ai_primary_keys});
 		$self->{log}->debug("Rdb_dman_init: field " . $id . " type: " . $c->type);
 	}
-	
+	if (defined $self->{alias}){
+		my %usedfor;
+		for my $field (keys %{$self->{alias}}){
+			my $aliaslist = $self->{alias}->{$field};
+			for my $alias (@{$aliaslist}){
+				$usedfor{$alias}= $field;
+				push @{$self->{cols}}, $alias;
+			}
+		}
+		$self->{isalias} = \%usedfor;
+	}
 	if (defined $self->{'+columns'}){ #use meta object from main table and from relationship (foreign key not treated with) for the moment
 
 		#$self->_get_fields_access($meta, $aref);
@@ -471,7 +491,7 @@ A new instance is created using an array of objects issue by a Rose::DB::Object:
 
 The parameters are passed as a list of parameters name => value, or as a hash reference with the parameters name as keys. 
 
-Parameters are C<data>, C<meta>, C<columns> or  C<'+columns'>.
+Parameters are C<data>, C<meta>, C<columns> or  C<'+columns'>, C<alias>.
 
 The value for C<data> is a reference to an array of Rose::SB::Object::Manager derived objects. The value for C<meta> is the corresponding metadata object.
 
@@ -485,6 +505,21 @@ Use C<+columns> if you are using fields from the main table and from joined tabl
 Use neither of them if you want to access fields from the main table only, the relationship being used to restrict the rows.
 The fields selected with C<'+columns'> or with C<'columns'> are readonly: a call to set_field($field_id, $field_value) will not change any value.
 
+C<alias> is a hash ref of field (key) and array ref (alias list). For example if my Speak.pm module define
+ 	__PACKAGE__->meta->setup(
+	    table   => 'speaks',
+
+	    columns => [
+        	speaksid  => { type => 'serial' },
+	        countryid => { type => 'integer', not_null => 1 },
+        	langid    => { type => 'integer', not_null => 1 },
+    	],
+
+    		primary_key_columns => [ 'speaksid' ],
+	);
+
+Giving C<alias => {langid => [qw(langid1 langid2)]},> in the constructor will enable the RdbDataManager to return the langid value when called with C< $dman->get_field('langid1')>. It is possible to add alias directly with using C<Rose::DB::Object::Metadata> but I confess I have not found out how...
+
 =head2 C<query( $data );>
 
 To display an other set of rows in a form, call the query method on the datamanager instance for this form with a new array of Rose::DB::Object derived objects.
