@@ -5,7 +5,7 @@ our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
 use strict;
 use warnings;
 use Data::Dumper;
-
+use Carp;
 use Try::Tiny;
 
 my %fieldtype = (tinyint => "integer", "int" => "integer");
@@ -166,7 +166,7 @@ sub _fetch_new_batch {
 			 #push @vals_for_pk, $pk_vals[$pk_order] unless ($seen{ $pk_vals[$pk_order] }++);
 			 if ($self->{pkvalues_filter}) {
 				 # if a primary key value is repeated 
-				 #(that means that the table rows are defined by several primary keys), 
+				 #(that means that the table rows are defined by several colums to form the primary key), 
 				 #it is stored once
 				 push @vals_for_pk, $pk_vals[$pk_order] unless ($seen{ $pk_vals[$pk_order] }++);
 			 } else {
@@ -238,7 +238,7 @@ sub set_field {
 sub get_field {
 my ($self, $fieldname) = @_;
   # $self->{log}->debug("get_field - name : " . $fieldname . "\nRecords: " . (Dumper $self->{records}));
-  confess ("get_field($fieldname) called on an empty recordset ! Did you forget to call set_row_pos(0) after query ?") unless ($self->{records});
+  carp ("get_field($fieldname) called on an empty recordset ! Did you forget to call set_row_pos(0) after query ?") unless ($self->{records});
    my $data = $self->{records}[$self->{batch_pos}]->{$fieldname};
    return $data;
 }
@@ -535,7 +535,7 @@ sub _use_sth_info {
  sub _add_to_cols {
  my ($self, $fieldname) = @_;
  	my %hcols = %{$self->{hcols}};
-	#$self->{log}->debug(Dumper %hcols);
+	$self->{log}->debug("_add_to_cols ", $fieldname)  unless (defined $hcols{$fieldname});
 	push @{$self->{cols}}, $fieldname unless (defined $hcols{$fieldname});
 	$hcols{$fieldname}++;
 	#$self->{hcols}->{$fieldname}++;
