@@ -167,10 +167,12 @@ sub query {
 	#each elements of the array is an array ref. The sub array holds the value(s) of the primary key(s) for a row.
         while ( my @row = $sth->fetchrow_array ) {
             my $key_no = 0;
-          my @key_vals; 
+          my @key_vals;
+	  # $self->{log}->debug(Dumper @row); 
             foreach my $pk ( @pks ) {
 		    # $self->{log}->debug("query : " . $primary_key . " value : " . $row[$key_no] );
-		 croak (__PACKAGE__ . ": no value found for primary key $pk .. check the sql command") unless($row[$key_no]);
+		    # if $row[$key_no] is 0 the test failed but a pk could have this value...
+		 croak (__PACKAGE__ . ": no value found for primary key $pk .. check the sql command") unless(defined $row[$key_no]);
 		 #push @keys, $row[$key_no];
 		 push @key_vals, $row[$key_no];
 		 #$self->{log}->debug("add ", $row[$key_no], " to array of pkvalues for pk ", $pk);
@@ -252,20 +254,10 @@ sub _get_rows_from_batch {
 }
 
 sub save {
-
-	# my ($self,  $href) = @_;
 	my $self = shift;
 	my %h;
 	 my $href = (ref $_[0] eq "HASH" ? $_[0] : (%h = (@_)) && \%h);
-=for comment
-	my $href;
-	if (ref $_[0] eq "HASH") {
-	      $href =  $_[0] 
-         } else {
-	     my %h =( @_);
-	     $href = \%h;
-         }
-=cut
+	
     my %new_values;
 	#my @fieldlist = ();
 	#my @bind_values = ();
@@ -281,18 +273,22 @@ sub save {
      my @pk;   
     if ($href) {
     	for my $k (keys %$href) {
-		$self->{log}->debug("add to new_values " .  $href->{$k} . " from field " . $k);
+		$self->{log}->debug("received with calling save " .  $href->{$k} . " from field " . $k);
 		#push @bind_values, $href->{$k};
 		#push @fieldlist, $k;
 		$new_values{$k} = $href->{$k};
+		if ($self->{inserting}) { #when updating existing pk value, the old value in dman are to be used 
+					# to select the row. -> no change
+			$self->set_field($k, $href->{$k});
+		}
 	}
 	# @pk = $self->get_primarykeys;
-    } else {
+    } #else {
 	 # @pk  = $self->get_autoinc_primarykeys;
 	#avec la table abo et la jointure sur jrnabt, la mise a jour ne marche pas car get_autoinc_primarykey retroune un vecteur vide
 	#noabt est alors traite comme un champ normal
 	#prendre toujours le resultat de get_primarykeys corrige ce probleme
-     }
+	#}
      @pk =  $self->get_primarykeys;
    $self->{log}->debug("pk: " . join(" ", @pk));
    $self->{log}->debug("primary_keys: " . join(" ", @{$self->{primary_keys}}));
@@ -310,7 +306,7 @@ my ($value, $stm, @bind);
 	#if ( $sql_fieldname ~~ @pk) {
 	if (grep (/\b$fieldname\b/, @pk)) {
 		my @keys = keys %new_values;
-		$self->{log}->debug("Not fetching value from $fieldname because it's a pk. ", 0 + @keys ? "The fetched values come from " . join(" ", @keys) : "");
+		$self->{log}->debug("Not fetching value from $fieldname because it's a pk. ");
 
             next;
         }
@@ -339,7 +335,7 @@ my ($value, $stm, @bind);
         
     } else {
         
-	
+	    #update: fetch the pk(s) value(s) for the row to update
 	
 	foreach my $primary_key ( @pk ) {
 		$primary_key=~s/^$table\.//;
@@ -350,28 +346,29 @@ my ($value, $stm, @bind);
         }
 
  	$self->{log}->debug("updating ", $table, " at rows with pks : ", Dumper %pk_values);
+	# run the update
 	 ($stm, @bind) = $self->{sql}->update(-table => $table, -set => \%new_values , -where => \%pk_values);
         
     }
   
       my $done = ( $self->_execute($stm, @bind) ? 1 : 0);
-    
-  
-    
-    # If this was an INSERT, we need to fetch the primary key value and apply it to the local slice,
-    # and also append the primary key to the keyset
-    
-    if ($done && $self->{auto_incrementing} && $self->{inserting} ) {
-        
-            my $new_key = $self->_last_insert_id;
+   
+     
+    if ($done  && $self->{inserting} ) {
+
+	     # update the datamanager with the value of autoinc pk given by the database 
+             if ($self->{auto_incrementing}) {
+                      my $new_key = $self->_last_insert_id;
 	    # my $primary_key = $self->{primary_keys}[0];
-	     my $primary_key = $pk[0];
+	              my $primary_key = $pk[0];
 	     #$self->{records}[$self->{slice_position}]->{ $self->{sql_to_widget_map}->{$primary_key} } = $new_key;
-	     $self->set_field($primary_key, $new_key);
+	              $self->set_field($primary_key, $new_key);
             
-        
+            }
+
+	#insert in a row defined by pk(s) that are autoinc or not autoinc
+	#add the pks names + values to the recordset object
         my @keys;
-        
         foreach my $primary_key ( @{$self->{primary_keys}} ) {
 		#my $value = $self->{records}[$self->{slice_position}]->{ $primary_key };
 		my $value = $self->get_field($primary_key);
@@ -379,12 +376,11 @@ my ($value, $stm, @bind);
             push @keys, $value ;
         }
         
-	#push @{$self->{keyset}}, @keys;
-	#push @{$self->{keyset}}, join(", ", @keys);
 	#in Recordset, pkvalues is an array ref of array, each array contains usualy one value for the a given row, but can contains 2 values if it's a composed primary key
 	$self->add_pkvalues(\@keys);
 	#$self->{log}->debug( join(", ", @keys) . " added to pkvalues");
-	#turn the flag only if $done is true... otherwise all subsequent atempts to save a new insert that has failed will be treated as updates (not inserts) and will failed also since no pk has been given.
+	#turn the flag only if $done is true... otherwise all subsequent atempts to save a new insert 
+	#that has failed will be treated as updates (not inserts) and will failed also since no pk has been given.
         $self->{inserting} = 0;
 	$self->{log}->debug("turn off inserting flag");
     }
@@ -424,7 +420,7 @@ sub delete {
 
 sub _execute {
 	my ($self, $sql, @bind) = @_;
-	#$self->{log}->debug("_execute:", $sql);
+	$self->{log}->debug("_execute:", $sql);
 	my $sth = $self->{dbh}->prepare($sql);
 	#my $done=0;
 	try {
@@ -443,7 +439,7 @@ sub _execute {
  sub _init_cols {
   my $self = shift;
  my $args = $self->{select_param};
-# my %aliased_columns;
+ my %aliased_columns;
    my @cols = ref $args->{-columns} ? @{$args->{-columns}} : $args->{-columns};
    # die Dumper @cols;
    if ($cols[0]){
@@ -457,14 +453,14 @@ sub _execute {
                  (\w+)        # followed by a word (the alias))
                  \s*          # ignore insignificant trailing spaces
                  $/x) {
-		 #$aliased_columns{$2} = $1;
+		 $aliased_columns{$2} = $1;
 	#$col = $self->column_alias($1, $2);
-				$col = ($2 ? $2 : $1);
+	#$col = ($2 ? $2 : $1);
     			}
 
-		$self->_add_to_cols($col);
+		$self->_add_to_cols($1) if (defined $1);
   	}
-	
+	$self->{isalias} = \%aliased_columns;
      } else {
 	my $w = $$args{-where};
 	$$args{-where}= {0 =>{'='=>\"1"}};
